# Inspector | Code Execution Monitoring Tool

Inspector is a Code Execution Monitoring tool to help developers find out technical problems in their software automatically, before customers do.

## Requirements

- Python >= 3.x

## Abstract
This library will allow Python developers to connect their applications to the Code Execution Monitoring tool Inspector.

The development is in progress under the direct management of the Inspector team. This is not a community project.

## License
This library is licensed under the [MIT](LICENSE) license.